@@ -1,16 +1,21 @@
 # Auto generated Python source file from Ada sources
 # Call 'make' in 'src/vhdl' to regenerate:
 #
-from pydecor import export
-from pyGHDL.libghdl import libghdl
+from enum import IntEnum, unique
+from pyTooling.Decorators import export
+
+from pyGHDL.libghdl._decorator import BindToLibGHDL
+
 
 @export
+@BindToLibGHDL("errorout__enable_warning")
 def Enable_Warning(Id: int, Enable: bool) -> None:
-    libghdl.errorout__enable_warning(Id, Enable)
+    """"""
 
 
 @export
-class Msgid:
+@unique
+class Msgid(IntEnum):
     Msgid_Note = 0
     Warnid_Library = 1
     Warnid_Deprecated_Option = 2
@@ -32,14 +37,16 @@ class Msgid:
     Warnid_Port_Bounds = 18
     Warnid_Runtime_Error = 19
     Warnid_Delta_Cycle = 20
-    Warnid_Shared = 21
-    Warnid_Hide = 22
-    Warnid_Unused = 23
-    Warnid_Others = 24
-    Warnid_Pure = 25
-    Warnid_Analyze_Assert = 26
-    Warnid_Attribute = 27
-    Warnid_Static = 28
-    Msgid_Warning = 29
-    Msgid_Error = 30
-    Msgid_Fatal = 31
+    Warnid_No_Wait = 21
+    Warnid_Shared = 22
+    Warnid_Hide = 23
+    Warnid_Unused = 24
+    Warnid_Others = 25
+    Warnid_Pure = 26
+    Warnid_Analyze_Assert = 27
+    Warnid_Attribute = 28
+    Warnid_Useless = 29
+    Warnid_Static = 30
+    Msgid_Warning = 31
+    Msgid_Error = 32
+    Msgid_Fatal = 33
