@@ -4,7 +4,7 @@ import json
 from ctypes import byref
 import pyGHDL.libghdl as libghdl
 import pyGHDL.libghdl.errorout_memory as errorout_memory
-import pyGHDL.libghdl.flags
+import pyGHDL.libghdl.flags as flags
 import pyGHDL.libghdl.errorout as errorout
 import pyGHDL.libghdl.files_map as files_map
 import pyGHDL.libghdl.libraries as libraries
@@ -12,7 +12,7 @@ import pyGHDL.libghdl.name_table as name_table
 import pyGHDL.libghdl.vhdl.nodes as nodes
 import pyGHDL.libghdl.vhdl.lists as lists
 import pyGHDL.libghdl.vhdl.std_package as std_package
-import pyGHDL.libghdl.vhdl.parse
+import pyGHDL.libghdl.vhdl.parse as parse
 import pyGHDL.libghdl.vhdl.sem_lib as sem_lib
 import pyGHDL.libghdl.utils as pyutils
 
@@ -23,7 +23,7 @@ log = logging.getLogger(__name__)
 
 
 class ProjectError(Exception):
-    "Exception raised in case of unrecoverable error in the project file."
+    """Exception raised in case of unrecoverable error in the project file."""
 
     def __init__(self, msg):
         super().__init__()
@@ -44,15 +44,15 @@ class Workspace(object):
         self._prj = {}
         self._last_linted_doc = None
         errorout_memory.Install_Handler()
-        libghdl.flags.Flag_Elocations.value = True
-        # libghdl.Flags.Verbose.value = True
+        flags.Flag_Elocations.value = True
+        # flags.Verbose.value = True
         # We do analysis even in case of errors.
-        libghdl.vhdl.parse.Flag_Parse_Parenthesis.value = True
+        parse.Flag_Parse_Parenthesis.value = True
         # Force analysis to get more feedback + navigation even in case
         # of errors.
-        libghdl.flags.Flag_Force_Analysis.value = True
+        flags.Flag_Force_Analysis.value = True
         # Do not consider analysis order issues.
-        libghdl.flags.Flag_Elaborate_With_Outdated.value = True
+        flags.Flag_Elaborate_With_Outdated.value = True
         libghdl.errorout.Enable_Warning(errorout.Msgid.Warnid_Unused, True)
         self.read_project()
         self.set_options_from_project()
@@ -96,9 +96,7 @@ class Workspace(object):
         path = lsp.path_from_uri(doc_uri)
         if source is None:
             source = open(path).read()
-        sfe = document.Document.load(
-            source, os.path.dirname(path), os.path.basename(path)
-        )
+        sfe = document.Document.load(source, os.path.dirname(path), os.path.basename(path))
         return self._create_document(doc_uri, sfe)
 
     def get_or_create_document(self, doc_uri):
@@ -110,8 +108,11 @@ class Workspace(object):
         return res
 
     def get_document(self, doc_uri):
-        """Get a document from :param doc_uri:  Note that the document may not exist,
-        and this function may return None."""
+        """
+        Get a document from :param doc_uri:
+
+        Note that the document may not exist, and this function may return None.
+        """
         return self._docs.get(doc_uri)
 
     def put_document(self, doc_uri, source, version=None):
@@ -126,8 +127,11 @@ class Workspace(object):
         return doc
 
     def sfe_to_document(self, sfe):
-        """Get the document correspond to :param sfe: source file.
-        Can create the document if needed."""
+        """
+        Get the document correspond to :param sfe: source file.
+
+        Can create the document if needed.
+        """
         assert sfe != 0
         doc = self._fe_map.get(sfe, None)
         if doc is None:
@@ -151,9 +155,7 @@ class Workspace(object):
             sfe = document.Document.load(fd.read(), self._root_path, name)
             fd.close()
         except OSError as err:
-            self._server.show_message(
-                lsp.MessageType.Error, "cannot load {}: {}".format(name, err.strerror)
-            )
+            self._server.show_message(lsp.MessageType.Error, "cannot load {}: {}".format(name, err.strerror))
             return
         doc = self.create_document_from_sfe(sfe, absname)
         doc.parse_document()
@@ -178,9 +180,7 @@ class Workspace(object):
             log.info("error in project file")
             self._server.show_message(
                 lsp.MessageType.Error,
-                "json error in project file {}:{}:{}".format(
-                    prj_file, e.lineno, e.colno
-                ),
+                "json error in project file {}:{}:{}".format(prj_file, e.lineno, e.colno),
             )
         f.close()
 
@@ -201,13 +201,9 @@ class Workspace(object):
             log.info("Using options: %s", ghdl_opts)
             for opt in ghdl_opts:
                 if not libghdl.set_option(opt):
-                    self._server.show_message(
-                        lsp.MessageType.Error, "error with option: {}".format(opt)
-                    )
+                    self._server.show_message(lsp.MessageType.Error, "error with option: {}".format(opt))
         except ProjectError as e:
-            self._server.show_message(
-                lsp.MessageType.Error, "error in project file: {}".format(e.msg)
-            )
+            self._server.show_message(lsp.MessageType.Error, "error in project file: {}".format(e.msg))
 
     def read_files_from_project(self):
         try:
@@ -224,14 +220,10 @@ class Workspace(object):
                 if lang == "vhdl":
                     self.add_vhdl_file(name)
         except ProjectError as e:
-            self._server.show_message(
-                lsp.MessageType.Error, "error in project file: {}".format(e.msg)
-            )
+            self._server.show_message(lsp.MessageType.Error, "error in project file: {}".format(e.msg))
 
     def get_configuration(self):
-        self._server.configuration(
-            [{"scopeUri": "", "section": "vhdl.maxNumberOfProblems"}]
-        )
+        self._server.configuration([{"scopeUri": "", "section": "vhdl.maxNumberOfProblems"}])
 
     def gather_diagnostics(self, doc):
         # Gather messages (per file)
@@ -288,7 +280,7 @@ class Workspace(object):
             self.publish_diagnostics(doc.uri, [])
 
     def obsolete_dependent_units(self, unit, antideps):
-        """Obsolete units that depends of :param unit:"""
+        """Obsolete units that depends of :param unit:."""
         udeps = antideps.get(unit, None)
         if udeps is None:
             # There are no units.
@@ -296,16 +288,14 @@ class Workspace(object):
         # Avoid infinite recursion
         antideps[unit] = None
         for un in udeps:
-            log.debug(
-                "obsolete %d %s", un, pyutils.name_image(nodes.Get_Identifier(un))
-            )
+            log.debug("obsolete %d %s", un, pyutils.name_image(nodes.Get_Identifier(un)))
             # Recurse
             self.obsolete_dependent_units(un, antideps)
-            if nodes.Get_Date_State(un) == nodes.Date_State.Disk:
+            if nodes.Get_Date_State(un) == nodes.DateStateType.Disk:
                 # Already obsolete!
                 continue
             # FIXME: just de-analyze ?
-            nodes.Set_Date_State(un, nodes.Date_State.Disk)
+            nodes.Set_Date_State(un, nodes.DateStateType.Disk)
             sem_lib.Free_Dependence_List(un)
             loc = nodes.Get_Location(un)
             fil = files_map.Location_To_File(loc)
@@ -370,12 +360,10 @@ class Workspace(object):
         )
 
     def show_message(self, message, msg_type=lsp.MessageType.Info):
-        self._server.notify(
-            "window/showMessage", params={"type": msg_type, "message": message}
-        )
+        self._server.notify("window/showMessage", params={"type": msg_type, "message": message})
 
     def declaration_to_location(self, decl):
-        "Convert declaration :param decl: to an LSP Location"
+        """Convert declaration :param decl: to an LSP Location."""
         decl_loc = nodes.Get_Location(decl)
         if decl_loc == std_package.Std_Location.value:
             # There is no real file for the std.standard package.
@@ -389,9 +377,7 @@ class Workspace(object):
         nid = nodes.Get_Identifier(decl)
         res["range"] = {
             "start": symbols.location_to_position(fe, decl_loc),
-            "end": symbols.location_to_position(
-                fe, decl_loc + name_table.Get_Name_Length(nid)
-            ),
+            "end": symbols.location_to_position(fe, decl_loc + name_table.Get_Name_Length(nid)),
         }
         return res
 
@@ -447,13 +433,7 @@ class Workspace(object):
         def create_interfaces(inters):
             res = []
             while inters != nodes.Null_Iir:
-                res.append(
-                    {
-                        "name": name_table.Get_Name_Ptr(
-                            nodes.Get_Identifier(inters)
-                        ).decode("latin-1")
-                    }
-                )
+                res.append({"name": name_table.Get_Name_Ptr(nodes.Get_Identifier(inters))})
                 inters = nodes.Get_Chain(inters)
             return res
 
@@ -476,7 +456,7 @@ class Workspace(object):
         }
 
     def compute_anti_dependences(self):
-        """Return a dictionnary of anti dependencies for design unit"""
+        """Return a dictionnary of anti dependencies for design unit."""
         res = {}
         lib = libraries.Get_Libraries_Chain()
         while lib != nodes.Null_Iir:
@@ -484,7 +464,7 @@ class Workspace(object):
             while files != nodes.Null_Iir:
                 units = nodes.Get_First_Design_Unit(files)
                 while units != nodes.Null_Iir:
-                    if nodes.Get_Date_State(units) == nodes.Date_State.Analyze:
+                    if nodes.Get_Date_State(units) == nodes.DateStateType.Analyze:
                         # The unit has been analyzed, so the dependencies are know.
                         deps = nodes.Get_Dependence_List(units)
                         assert deps != nodes.Null_Iir_List
