@@ -73,8 +73,7 @@ class ParseError(Exception):
         self.msg = msg
 
     def __str__(self):
-        return ("Parse error at {lr.filname}:{lr.lineno}: {msg}".format(lr=self.lr, msg=self.msg))
-
+        return ("Parse error at {lr.filename}:{lr.lineno}: {msg}".format(lr=self.lr, msg=self.msg))
 
 
 # Return fields description.
@@ -201,7 +200,7 @@ def read_kinds(filename):
             name = m.group(1)
             if not name.startswith(prefix_range_name):
                 raise ParseError(lr, "incorrect prefix for subtype")
-            name = name[len(prefix_range_name) :]
+            name = name[len(prefix_range_name):]
             l = lr.get()
             mf = pat_first.match(l)
             if not mf:
@@ -235,13 +234,16 @@ def read_kinds(filename):
                             )
                         break
                     raise ParseError(lr, "unhandled line in subtype")
-            kinds_ranges[name] = kinds[first : last + 1]
+            kinds_ranges[name] = kinds[first: last + 1]
     return (kinds, kinds_ranges)
 
 
 # Read functions
 def read_methods(filename):
     lr = linereader(filename)
+    # Note: this is a list so that the output is deterministic.
+    # Duplicates are not detected, but they will be by the Ada compiler.
+    # TODO: use an ordered dict ?
     funcs = []
     pat_field = re.compile(r"   --  Field: ([\w,]+)( \w+)?( \(\w+\))?\n")
     pat_conv = re.compile(r"^ \((\w+)\)$")
@@ -474,7 +476,7 @@ def gen_choices(choices):
     print(" =>")
 
 
-def gen_get_format(formats, nodes, kinds):
+def gen_get_format(formats, nodes, kinds=None):
     """Generate the Get_Format function."""
     print("   function Get_Format (Kind : " + type_name + ") " + "return Format_Type is")
     print("   begin")
