@@ -26,7 +26,7 @@
    set rights.
 */
 
-#ifdef __APPLE__
+#if defined(__APPLE__) || defined(__OpenBSD__)
 #define MAP_ANONYMOUS MAP_ANON
 #else
 #define HAVE_MREMAP
