@@ -5,12 +5,8 @@
 analyze test_load.vhdl
 elab test_load
 
-if ghdl_has_feature test_load vpi; then
-  if [ "$OS" = "Windows_NT" ]; then
-      vpi_lib=`$GHDL --vpi-library-dir | sed -e 's!\\\\!/!g' -e 's!^C:!/C!g'`
-      echo vpi_lib: $vpi_lib
-      PATH="$PATH:$vpi_lib"
-  fi
+if c_compiler_is_available && ghdl_has_feature test_load vpi; then
+  add_vpi_path
 
   $GHDL --vpi-compile -v gcc -c vpi1.c
   $GHDL --vpi-link -v gcc -o vpi1.vpi vpi1.o
