@@ -2,9 +2,7 @@
 
 . ../../testenv.sh
 
-for t in const01; do
-    synth_tb $t
-done
+synth_tb const01
 
 # synth const02.vhdl -e > syn_const02.vhdl
 synth_analyze const03
