@@ -1,4 +1,4 @@
-#! /bin/bash
+#! /usr/bin/env bash
 
 # Stop in case of error
 set -e
@@ -19,6 +19,11 @@ enable_color() {
 disable_color() { unset ENABLECOLOR ANSI_RED ANSI_GREEN ANSI_YELLOW ANSI_BLUE ANSI_MAGENTA ANSI_CYAN ANSI_DARKCYAN ANSI_NOCOLOR; }
 enable_color
 
+die() {
+  printf "${ANSI_RED}%s${ANSI_NOCOLOR}\n" "$@" >&2
+  exit 1
+}
+
 print_start() {
   COL="$ANSI_YELLOW"
   if [ "x$2" != "x" ]; then
@@ -78,11 +83,19 @@ if [ "x$GHDL" = "x" ]; then
   elif [ "x$(command -v which)" != "x" ]; then
     export GHDL="$(which ghdl)"
   else
-    printf "${ANSI_RED}error: GHDL environment variable is not defined${ANSI_NOCOLOR}\n"
-    exit 1
+    die "error: GHDL environment variable is not defined"
   fi
 fi
 
+if [ "$GHWDUMP" = "" ]; then
+  case "$GHDL" in
+    */*) export GHWDUMP=${GHDL%/*}/ghwdump;;
+    *) export GHWDUMP=ghwdump;;
+  esac
+fi
+
+command -v "$GHWDUMP" >/dev/null || die "ghwdump executable not found: $GHWDUMP"
+
 cd $(dirname "$0")
 rm -f test_ok
 failures=""
@@ -97,7 +110,7 @@ for opt; do
   esac
 done
 
-if [ "x$tests" = "x" ]; then tests="sanity pyunit gna vests synth vpi"; fi
+if [ "x$tests" = "x" ]; then tests="sanity pyunit gna vests synth vpi vhpi"; fi
 
 echo "> tests: $tests"
 echo "> args: $@"
@@ -105,7 +118,7 @@ echo "> args: $@"
 # Run a testsuite
 do_test() {
   case $1 in
-    sanity|gna|synth|vpi)
+    sanity|gna|synth|vpi|vhpi)
       gstart "[GHDL - test] $1"
       cd "$1"
       ../suite_driver.sh $@
@@ -117,7 +130,7 @@ do_test() {
     pyunit)
       # The Python Unit testsuite: regression testsuite for Python bindings to libghdl
       gstart "[GHDL - test] pyunit"
-      PYTHONPATH=$(pwd)/.. python3 -m pytest -rA pyunit
+      PYTHONPATH=$(pwd)/.. ${PYTHON:-python3} -m pytest -vsrA pyunit
       gend
     ;;
 
@@ -125,8 +138,8 @@ do_test() {
       _vests
     ;;
     *)
-      printf "${ANSI_RED}$0: test name '$1' is unknown${ANSI_NOCOLOR}\n"
-      exit 1;;
+      die "$0: test name '$1' is unknown"
+    ;;
   esac
 }
 
